@@ -25,13 +25,13 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-message-area.h 6138 2008-02-01 14:32:22Z icq $
+ * $Id$
  */
 
 #ifndef __GEDIT_MESSAGE_AREA_H__
 #define __GEDIT_MESSAGE_AREA_H__
 
-#include <gtk/gtkhbox.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
